@@ -4,7 +4,17 @@ import circuitsvis.activations
 import circuitsvis.attention
 import circuitsvis.examples
 import circuitsvis.tokens
+import circuitsvis.topk_samples
+import circuitsvis.topk_tokens
+import circuitsvis.logits
 
 __version__ = version("circuitsvis")
 
-__all__ = ["activations", "attention", "examples", "tokens"]
+__all__ = [
+    "activations",
+    "attention",
+    "examples",
+    "tokens",
+    "topk_samples",
+    "topk_tokens",
+]
