@@ -1,11 +1,12 @@
-from circuitsvis.examples import hello
+import circuitsvis
 import circuitsvis.utils.render
+from circuitsvis.examples import hello
 
 
 class TestHello:
     def test_matches_snapshot(self, snapshot, monkeypatch):
-        # Monkeypatch uuid4 to always return the same uuid
         monkeypatch.setattr(circuitsvis.utils.render, "uuid4", lambda: "mock")
+        monkeypatch.setattr(circuitsvis, "__version__", "1.0.0")
 
         res = hello(name="Bob")
         snapshot.assert_match(str(res))
